@@ -53,6 +53,10 @@ See `imenu-generic-expression'.")
   '("condition_message_accesor" "description" "do_not_translate" "hidden" "install_requires" "language" "messages" "optional" "required_by" "requires_datamodel" "requires_java" "requires" "tests_modules" "test" "templates" "end")
   "List of Magik module keywords.")
 
+(defvar magik-module-installation-keywords
+  '("ace_installation" "auth_installation" "case_installation" "style_installation" "system_installation")
+  "List of Magik module installation keywords.")
+
 (defgroup magik-module-faces nil
   "Faces for displaying text in a Magik module.def file."
   :group 'magik-module)
@@ -86,11 +90,13 @@ See `imenu-generic-expression'.")
 (defcustom magik-module-font-lock-keywords
   (list
    (list (concat "^\\<\\(" (mapconcat 'identity magik-module-keywords "\\|") "\\)") 0 ''magik-module-keyword-face t)
-   '("^\\(\\sw+\\)\\s-*$"
+   (list (concat "^\\<\\(" (mapconcat 'identity magik-module-installation-keywords "\\|") "\\)") 0 ''magik-module-keyword-face t)
+   '("^\\([[:word:]!]+\\)\\s-*$"
      (1 'magik-module-name-face))
-   '("^\\(\\sw+\\)\\s-+\\([0-9]+\\(?:\\s-*[0-9]+\\)?\\)"
+   '("^\\([[:word:]!]+\\)\\s-+\\([0-9]+\\(?:\\s-*[0-9]+\\)?\\)"
      (1 'magik-module-name-face)
-     (2 'magik-number-face)))
+     (2 'magik-number-face))
+   (list (concat "^\\<\\(" (mapconcat 'identity magik-module-keywords "\\|") "\\)\\>") 0 ''magik-module-keyword-face t))
   "Default fontification of module.def files."
   :group 'magik-module
   :type 'sexp)
@@ -124,6 +130,7 @@ You can customize Module Mode with the `magik-module-mode-hook`.
   :abbrev-table nil
 
   (compat-call setq-local
+               comment-start-skip "#+ *"
                require-final-newline t
                imenu-generic-expression magik-module-imenu-generic-expression
                font-lock-defaults '(magik-module-font-lock-keywords nil t)))
